<?php
// $Id: flexiaccess.pages.inc,v 1.2 2010/11/04 13:14:07 goodman Exp $

function flexiaccess_page($form, &$form_state, $node) {
  // Get active content types that have flexi access managing their ACL
  $types = variable_get('flexiaccess_types', array());
  $ntype = $node->type;

  if (isset($types[$ntype]) && ($types[$ntype]) && module_exists('acl')) {
    // ACL stuff
    $form['acl'] = array(
      '#type' => 'fieldset',
      '#title' => t('User based ACL'),
      '#description' => t('Grant individual users access to this node based on their role\'s permissions.'),
      '#collapsible' => TRUE,
      '#tree' => TRUE,
    );
    foreach (array('view', 'update', 'delete') as $op) {
      $acl_id = flexiaccess_get_acl_id($node, $op);
      acl_node_add_acl($node->nid, $acl_id, (int)($op == 'view'), (int)($op == 'update'), (int)($op == 'delete'));

      $form['acl'][$op] = acl_edit_form($form_state, $acl_id, t('Grant !op permission', array('!op' => $op)));
      $form['acl'][$op]['#collapsed'] = !isset($_POST['acl_'. $acl_id]) && !unserialize($form['acl'][$op]['user_list']['#default_value']);
    }

    $form_state['node'] = $node;
    $form['submit'] = array(
      '#type' => 'submit',
      '#value' => t('Submit'),
      '#weight' => 10,
    );
    $form['reset'] = array(
      '#type' => 'submit',
      '#value' => t('Reset to defaults'),
      '#weight' => 11,
      '#submit' => array('flexiaccess_page_reset'),
    );

    if (!$node->status) {
      drupal_set_message(t("Warning: Your content is not published, so this settings are not taken into account as long as the content remains unpublished."), 'error');
    }

    return $form;
  }

  drupal_set_message(t('This content type is not managed by flexi access.'), 'error');
}

function flexiaccess_page_submit($form, &$form_state) {
  $settings = array();
  $node = $form_state['node'];

  if (module_exists('acl')) {
    foreach (array('view', 'update', 'delete') as $op) {
      acl_save_form($form_state['values']['acl'][$op]);
    }
  }

  // Apply new settings.
  node_access_acquire_grants($node);
  cache_clear_all();

  drupal_set_message(t('Your new ACL has been saved.'));
}

function flexiaccess_page_reset($form, &$form_state) {
  flexiaccess_delete_per_node_settings($form_state['node']);
  cache_clear_all();
  drupal_set_message(t('The permissions have been reseted.'));
}

/**
 * Deletes all custom per node settings, so that content type defaults are used again.
 */
function flexiaccess_delete_per_node_settings($node) {
  if (module_exists('acl')) {
    foreach (array('view', 'update', 'delete') as $op) {
      $acl_id = flexiaccess_get_acl_id($node, $op);
      acl_delete_acl($acl_id);
    }
  }
}